$ErrorActionPreference = 'Stop'

Login-AzureRmAccount

$subscriptionId = 
    (Get-AzureRmSubscription |
     Out-GridView `
        -Title "Select an Azure Subscription and click OK" `
        -PassThru).SubscriptionId

Select-AzureRmSubscription `
    -SubscriptionId $subscriptionId

# Deployment specific variables 
$location   = "westus"

# Get credentials for local account creation on VMs
$cred = Get-Credential -Message "Enter VM Local Account Admin Credentials"

# Resource group values
$rgName     = "WGVMRG"   
$rgVNETName = "WGVNetRG" 
$VNETName   = "WGVNet"

#Create VM Resource Group if it does not exist
Get-AzureRmResourceGroup -Name $rgName -ev notPresent -ea 0
if ($notPresent)
{
     Write-Host "Resource group did not exist...creating..." -ForegroundColor Green
     New-AzureRmResourceGroup -Name $rgName -Location $location
}
else
{
    Write-Host "Resource Group already exists...proceeding." -ForegroundColor Green
}

# Create storage account if it does not exist
$sa = Get-AzureRmStorageAccount -ResourceGroupName $rgName

If (!$sa) 
    {

    $saPrefix  = "wgsa"
    $saType    = "Standard_LRS"

    $randomnumber = Get-Random -Minimum 0 -Maximum 9999
    $tempName = $saPrefix + $randomnumber
    $var1 = Get-AzureRmStorageAccountNameAvailability -Name $tempName
    If ($var1.NameAvailable -ne $True) {
        Do {
            $randomnumber = Get-Random -Minimum 0 -Maximum 9999
            $tempName = $saPrefix + $randomnumber
            $var1 = Get-AzureRmStorageAccountNameAvailability -Name $tempName
            }
        Until ($var1.NameAvailable -eq $True)
    }
    $saName = $tempName

    $storageAcc = New-AzureRmStorageAccount -ResourceGroupName $rgName `
         -Name $saName -Type $saType -Location $location

    $blobEndpoint = $storageAcc.PrimaryEndpoints.Blob.ToString()
    }
Else {
    Write-Host "Storage Account already exists...preceeding" -ForegroundColor Green
    }


# Create resources shared by Web servers
# Create availability set
$avSetName  = "WEBAS"
$avSet = New-AzureRmAvailabilitySet -ResourceGroupName $rgName `
                                    -Name $avSetName -Location $location

# Variables for all VM creation
$pubName    = "MicrosoftWindowsServer"
$offerName  = "WindowsServer"
$skuName    = "2012-R2-Datacenter"
$vmSize     = "Standard_D1_V2"

# Creation of WGWEB11
# Variables for WGWEB1
$vmName     = "WGWEB1"
$ipName     = $vmName + "IP"
$nicName    = $vmName + "VMNIC1"

Write-Host "Getting Existing Resources from resource group $rgName" -ForegroundColor Green

# Get a reference to the existing virtual network 
$vnet = Get-AzureRmVirtualNetwork -ResourceGroupName $rgVNETName `
                                  -Name $VNETName

Write-Host "Creating new resources for VM $vmName" -ForegroundColor Green

# Create a new network interface in the Apps subnet .Subnets[0]
$nic = New-AzureRmNetworkInterface -Name $nicName `
                                 -ResourceGroupName $rgName `
                                 -Location $location `
                                 -SubnetId $vnet.Subnets[2].Id `

# Create a new virtual machine configuration object
$vm = New-AzureRmVMConfig -VMName $vmName -VMSize $vmSize `
                          -AvailabilitySetId $avSet.Id

# Associate the network interface with the VM 
Add-AzureRmVMNetworkInterface -Id $nic.Id -VM $vm


# Set the OS credentials
Set-AzureRmVMOperatingSystem -Windows `
                             -ComputerName $vmName `
                             -Credential $cred `
                             -ProvisionVMAgent `
                             -VM $vm

# Set the source image 
Set-AzureRmVMSourceImage -PublisherName $pubName `
                         -Offer $offerName `
                         -Skus $skuName `
                         -Version "latest" `
                         -VM $vm

# Set the OS disk location 
$osDiskName = "WGWEB1-osdisk"
$osDiskUri    = $blobEndpoint + "vhds/" + $osDiskName  + ".vhd"

# Set the OS disk on the virtual machine configuration
Set-AzureRmVMOSDisk -Name $osDiskName `
                    -VhdUri $osDiskUri `
                    -CreateOption fromImage `
                    -VM $vm

Write-Host "Creating virtual machine $vmName" -ForegroundColor Green

# Create the virtual machine 
New-AzureRmVM -ResourceGroupName $rgName -Location $location -VM $vm

# Creation of WGWEB2
# Variables for WGWEB2
$vmName     = "WGWEB2"
$ipName     = $vmName + "IP"
$nicName    = $vmName + "VMNIC1"

Write-Host "Creating new resources for VM $vmName" -ForegroundColor Green

# Create a new network interface in the Apps subnet .Subnets[0]
$nic = New-AzureRmNetworkInterface -Name $nicName `
                                 -ResourceGroupName $rgName `
                                 -Location $location `
                                 -SubnetId $vnet.Subnets[2].Id `

# Create a new virtual machine configuration object
$vm = New-AzureRmVMConfig -VMName $vmName -VMSize $vmSize `
                          -AvailabilitySetId $avSet.Id

# Associate the network interface with the VM 
Add-AzureRmVMNetworkInterface -Id $nic.Id -VM $vm


# Set the OS credentials
Set-AzureRmVMOperatingSystem -Windows `
                             -ComputerName $vmName `
                             -Credential $cred `
                             -ProvisionVMAgent `
                             -VM $vm

# Set the source image 
Set-AzureRmVMSourceImage -PublisherName $pubName `
                         -Offer $offerName `
                         -Skus $skuName `
                         -Version "latest" `
                         -VM $vm

# Set the OS disk location 
$osDiskName = "WGWEB2-osdisk"
$osDiskUri    = $blobEndpoint + "vhds/" + $osDiskName  + ".vhd"

# Set the OS disk on the virtual machine configuration
Set-AzureRmVMOSDisk -Name $osDiskName `
                    -VhdUri $osDiskUri `
                    -CreateOption fromImage `
                    -VM $vm

Write-Host "Creating virtual machine $vmName" -ForegroundColor Green

# Create the virtual machine 
New-AzureRmVM -ResourceGroupName $rgName -Location $location -VM $vm

# Creation of WGSQL1
# Variables for WGWEB1
$pubName    = "MicrosoftSQLServer"
$offerName  = "SQL2014SP1-WS2012R2"
$skuName    = "Web"
$vmName     = "WGSQL1"
$ipName     = $vmName + "IP"
$nicName    = $vmName + "VMNIC1"

Write-Host "Creating new resources for VM $vmName" -ForegroundColor Green

# Create a new network interface in the Data subnet .Subnets[1].Id
$nic = New-AzureRmNetworkInterface -Name $nicName `
                                 -ResourceGroupName $rgName `
                                 -Location $location `
                                 -SubnetId $vnet.Subnets[3].Id 

# Create a new virtual machine configuration object
$vm = New-AzureRmVMConfig -VMName $vmName -VMSize $vmSize 

# Associate the network interface with the VM 
Add-AzureRmVMNetworkInterface -Id $nic.Id -VM $vm

# Create the URI for data disk 1
$dataDiskName = $vmName + "-datadisk1" 
$dataDiskUri = $blobEndpoint + "vhds/" + $dataDiskName  + ".vhd"

# Attach data disk 1 to the VM configuration
Add-AzureRmVMDataDisk -Name $dataDiskName `
                      -VhdUri $dataDiskUri -Caching None `
                      -DiskSizeInGB 1023 -Lun 0 -CreateOption empty `
                      -VM $vm

# Create the URI for data disk 2
$dataDiskName = $vmName + "-datadisk2" 
$dataDiskUri = $blobEndpoint + "vhds/" + $dataDiskName  + ".vhd"

# Attach data disk 2 to the VM configuration 
Add-AzureRmVMDataDisk -Name $dataDiskName `
                      -VhdUri $dataDiskUri -Caching None `
                      -DiskSizeInGB 1023 -Lun 1 -CreateOption empty `
                      -VM $vm


# Set the local administrative credentials 
Set-AzureRmVMOperatingSystem -Windows `
                             -ComputerName $vmName `
                             -Credential $cred `
                             -ProvisionVMAgent  `
                             -VM $vm

# Set the source image 
Set-AzureRmVMSourceImage -PublisherName $pubName `
                         -Offer $offerName `
                         -Skus $skuName `
                         -Version "latest" `
                         -VM $vm

# Create the URI to the OS disk of the SLQ server
$osDiskName = $vmName + "-osdisk0"
$osDiskUri    = $blobEndpoint + "vhds/" + $osDiskName  + ".vhd"

# Set the OS disk on the VM configuration object
Set-AzureRmVMOSDisk -Name $osDiskName `
                    -VhdUri $osDiskUri `
                    -CreateOption fromImage `
                    -VM $vm

Write-Host "Creating virtual machine $vmName" -ForegroundColor Green


# Create the VM 
New-AzureRmVM -ResourceGroupName $rgName `
                -Location $location `
                -VM $vm

Write-Host "VM creation complete..." -ForegroundColor Green